/* AppDirs.c generated by valac 0.40.4, the Vala compiler
 * generated from AppDirs.vala, do not modify */

/* Copyright 2016 Software Freedom Conservancy Inc.
 *
 * This software is licensed under the GNU LGPL (version 2.1 or later).
 * See the COPYING file in this distribution.
 */


#include <glib.h>
#include <glib-object.h>
#include <gio/gio.h>
#include <stdlib.h>
#include <string.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <glib/gi18n-lib.h>
#include <glib/gstdio.h>
#include <time.h>
#include <gobject/gvaluecollector.h>


#define TYPE_APP_DIRS (app_dirs_get_type ())
#define APP_DIRS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_APP_DIRS, AppDirs))
#define APP_DIRS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_APP_DIRS, AppDirsClass))
#define IS_APP_DIRS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_APP_DIRS))
#define IS_APP_DIRS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_APP_DIRS))
#define APP_DIRS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_APP_DIRS, AppDirsClass))

typedef struct _AppDirs AppDirs;
typedef struct _AppDirsClass AppDirsClass;
typedef struct _AppDirsPrivate AppDirsPrivate;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

#define TYPE_CONFIGURATION_FACADE (configuration_facade_get_type ())
#define CONFIGURATION_FACADE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CONFIGURATION_FACADE, ConfigurationFacade))
#define CONFIGURATION_FACADE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CONFIGURATION_FACADE, ConfigurationFacadeClass))
#define IS_CONFIGURATION_FACADE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CONFIGURATION_FACADE))
#define IS_CONFIGURATION_FACADE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CONFIGURATION_FACADE))
#define CONFIGURATION_FACADE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CONFIGURATION_FACADE, ConfigurationFacadeClass))

typedef struct _ConfigurationFacade ConfigurationFacade;
typedef struct _ConfigurationFacadeClass ConfigurationFacadeClass;

#define CONFIG_TYPE_FACADE (config_facade_get_type ())
#define CONFIG_FACADE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CONFIG_TYPE_FACADE, ConfigFacade))
#define CONFIG_FACADE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CONFIG_TYPE_FACADE, ConfigFacadeClass))
#define CONFIG_IS_FACADE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CONFIG_TYPE_FACADE))
#define CONFIG_IS_FACADE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CONFIG_TYPE_FACADE))
#define CONFIG_FACADE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CONFIG_TYPE_FACADE, ConfigFacadeClass))

typedef struct _ConfigFacade ConfigFacade;
typedef struct _ConfigFacadeClass ConfigFacadeClass;
#define _g_date_time_unref0(var) ((var == NULL) ? NULL : (var = (g_date_time_unref (var), NULL)))
typedef struct _ParamSpecAppDirs ParamSpecAppDirs;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _AppDirs {
	GTypeInstance parent_instance;
	volatile int ref_count;
	AppDirsPrivate * priv;
};

struct _AppDirsClass {
	GTypeClass parent_class;
	void (*finalize) (AppDirs *self);
};

struct _ParamSpecAppDirs {
	GParamSpec parent_instance;
};


static gpointer app_dirs_parent_class = NULL;
static GFile* app_dirs_exec_dir;
static GFile* app_dirs_exec_dir = NULL;
static GFile* app_dirs_data_dir;
static GFile* app_dirs_data_dir = NULL;
static GFile* app_dirs_tmp_dir;
static GFile* app_dirs_tmp_dir = NULL;
static GFile* app_dirs_libexec_dir;
static GFile* app_dirs_libexec_dir = NULL;

gpointer app_dirs_ref (gpointer instance);
void app_dirs_unref (gpointer instance);
GParamSpec* param_spec_app_dirs (const gchar* name,
                                 const gchar* nick,
                                 const gchar* blurb,
                                 GType object_type,
                                 GParamFlags flags);
void value_set_app_dirs (GValue* value,
                         gpointer v_object);
void value_take_app_dirs (GValue* value,
                          gpointer v_object);
gpointer value_get_app_dirs (const GValue* value);
GType app_dirs_get_type (void) G_GNUC_CONST;
#define APP_DIRS_DEFAULT_DATA_DIR "shotwell"
void app_dirs_init (const gchar* arg0);
void app_dirs_terminate (void);
GFile* app_dirs_get_home_dir (void);
GFile* app_dirs_get_cache_dir (void);
void app_dirs_try_migrate_data (void);
GFile* app_dirs_get_user_plugins_dir (void);
GFile* app_dirs_get_data_dir (void);
void app_window_panic (const gchar* msg);
void app_dirs_set_data_dir (const gchar* user_data_dir);
gboolean is_string_empty (const gchar* s);
gchar* strip_pretty_path (const gchar* path);
void app_dirs_verify_data_dir (void);
void app_dirs_verify_cache_dir (void);
GFile* app_dirs_get_libexec_dir (void);
GFile* app_dirs_get_install_dir (void);
GFile* app_dirs_get_exec_dir (void);
#define RESOURCES_LIBEXECDIR _LIBEXECDIR
GFile* get_sys_install_dir (GFile* exec_dir);
GFile* app_dirs_get_import_dir (void);
GType configuration_facade_get_type (void) G_GNUC_CONST;
GType config_facade_get_type (void) G_GNUC_CONST;
ConfigFacade* config_facade_get_instance (void);
gchar* configuration_facade_get_import_dir (ConfigurationFacade* self);
GFile* app_dirs_get_baked_import_dir (time_t tm);
gchar* configuration_facade_get_directory_pattern (ConfigurationFacade* self);
gchar* configuration_facade_get_directory_pattern_custom (ConfigurationFacade* self);
gboolean app_dirs_is_in_import_dir (GFile* file);
void app_dirs_set_import_dir (const gchar* path);
void configuration_facade_set_import_dir (ConfigurationFacade* self,
                                          const gchar* import_dir);
GFile* app_dirs_get_temp_dir (void);
GFile* app_dirs_get_data_subdir (const gchar* name,
                                 const gchar* subname);
void app_dirs_ensure_writable (GFile* dir);
GFile* app_dirs_get_cache_subdir (const gchar* name,
                                  const gchar* subname);
GFile* app_dirs_get_lib_dir (void);
#define RESOURCES_LIB _LIB
GFile* app_dirs_get_system_plugins_dir (void);
GFile* app_dirs_get_log_file (void);
GFile* app_dirs_get_thumbnailer_bin (void);
GFile* app_dirs_get_settings_migrator_bin (void);
AppDirs* app_dirs_new (void);
AppDirs* app_dirs_construct (GType object_type);
static void app_dirs_finalize (AppDirs * obj);


void
app_dirs_init (const gchar* arg0)
{
	GFile* exec_file = NULL;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	GFile* _tmp4_;
	GFile* _tmp5_;
	GFile* _tmp6_;
#line 16 "/home/jens/Source/shotwell/src/AppDirs.vala"
	g_return_if_fail (arg0 != NULL);
#line 17 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp0_ = g_find_program_in_path (arg0);
#line 17 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp1_ = _tmp0_;
#line 17 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp2_ = realpath (_tmp1_, NULL);
#line 17 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp3_ = _tmp2_;
#line 17 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp4_ = g_file_new_for_path (_tmp3_);
#line 17 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp5_ = _tmp4_;
#line 17 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_g_free0 (_tmp3_);
#line 17 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_g_free0 (_tmp1_);
#line 17 "/home/jens/Source/shotwell/src/AppDirs.vala"
	exec_file = _tmp5_;
#line 18 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp6_ = g_file_get_parent (exec_file);
#line 18 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_g_object_unref0 (app_dirs_exec_dir);
#line 18 "/home/jens/Source/shotwell/src/AppDirs.vala"
	app_dirs_exec_dir = _tmp6_;
#line 16 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_g_object_unref0 (exec_file);
#line 191 "AppDirs.c"
}


void
app_dirs_terminate (void)
{
}


GFile*
app_dirs_get_home_dir (void)
{
	GFile* result = NULL;
	const gchar* _tmp0_;
	GFile* _tmp1_;
#line 27 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp0_ = g_get_home_dir ();
#line 27 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp1_ = g_file_new_for_path (_tmp0_);
#line 27 "/home/jens/Source/shotwell/src/AppDirs.vala"
	result = _tmp1_;
#line 27 "/home/jens/Source/shotwell/src/AppDirs.vala"
	return result;
#line 215 "AppDirs.c"
}


static gpointer
_g_object_ref0 (gpointer self)
{
#line 33 "/home/jens/Source/shotwell/src/AppDirs.vala"
	return self ? g_object_ref (self) : NULL;
#line 224 "AppDirs.c"
}


GFile*
app_dirs_get_cache_dir (void)
{
	GFile* result = NULL;
	GFile* _tmp0_ = NULL;
	GFile* _tmp1_;
#line 31 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp1_ = app_dirs_data_dir;
#line 31 "/home/jens/Source/shotwell/src/AppDirs.vala"
	if (_tmp1_ == NULL) {
#line 238 "AppDirs.c"
		const gchar* _tmp2_;
		GFile* _tmp3_;
		GFile* _tmp4_;
		GFile* _tmp5_;
#line 32 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp2_ = g_get_user_cache_dir ();
#line 32 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp3_ = g_file_new_for_path (_tmp2_);
#line 32 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp4_ = _tmp3_;
#line 32 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp5_ = g_file_get_child (_tmp4_, APP_DIRS_DEFAULT_DATA_DIR);
#line 32 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_g_object_unref0 (_tmp0_);
#line 32 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp0_ = _tmp5_;
#line 32 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_g_object_unref0 (_tmp4_);
#line 257 "AppDirs.c"
	} else {
		GFile* _tmp6_;
		GFile* _tmp7_;
#line 33 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp6_ = app_dirs_data_dir;
#line 33 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp7_ = _g_object_ref0 (_tmp6_);
#line 33 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_g_object_unref0 (_tmp0_);
#line 33 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp0_ = _tmp7_;
#line 269 "AppDirs.c"
	}
#line 31 "/home/jens/Source/shotwell/src/AppDirs.vala"
	result = _tmp0_;
#line 31 "/home/jens/Source/shotwell/src/AppDirs.vala"
	return result;
#line 275 "AppDirs.c"
}


void
app_dirs_try_migrate_data (void)
{
	GFile* user_plugin_dir = NULL;
	GFile* _tmp0_;
	GFile* old_dir = NULL;
	GFile* _tmp1_;
	GFile* _tmp2_;
	GFile* _tmp3_;
	GFile* _tmp4_;
	GFile* _tmp5_;
	GFile* _tmp6_;
	GFile* _tmp7_;
	GFile* _tmp8_;
	gboolean _tmp9_ = FALSE;
	GFile* _tmp10_;
	GFile* new_dir = NULL;
	GFile* _tmp19_;
	GFile* _tmp20_;
	GFile* _tmp21_;
	GFile* _tmp22_;
	gboolean _tmp23_ = FALSE;
	GFile* _tmp24_;
	GFile* cache_dir = NULL;
	GFile* _tmp26_;
	mode_t mask = {0};
	GFile* _tmp27_;
	GFile* _tmp36_;
	GFile* _tmp37_;
	GFile* _tmp38_;
	gchar* _tmp39_;
	gchar* _tmp40_;
	GFile* _tmp41_;
	GFile* _tmp42_;
	GFile* _tmp43_;
	gchar* _tmp44_;
	gchar* _tmp45_;
	GFile* _tmp46_;
	GFile* _tmp47_;
	GFile* _tmp48_;
	gboolean _tmp49_;
	GFile* _tmp62_;
	gchar* _tmp63_;
	gchar* _tmp64_;
	GFile* _tmp65_;
	gchar* _tmp66_;
	gchar* _tmp67_;
	GFile* _tmp68_;
	gchar* _tmp69_;
	gchar* _tmp70_;
	mode_t _tmp71_;
	GError * _inner_error_ = NULL;
#line 38 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp0_ = app_dirs_get_user_plugins_dir ();
#line 38 "/home/jens/Source/shotwell/src/AppDirs.vala"
	user_plugin_dir = _tmp0_;
#line 39 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp1_ = app_dirs_get_home_dir ();
#line 39 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp2_ = _tmp1_;
#line 39 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp3_ = g_file_get_child (_tmp2_, ".gnome2");
#line 39 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp4_ = _tmp3_;
#line 39 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp5_ = g_file_get_child (_tmp4_, "shotwell");
#line 39 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp6_ = _tmp5_;
#line 39 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp7_ = g_file_get_child (_tmp6_, "plugins");
#line 39 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp8_ = _tmp7_;
#line 39 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_g_object_unref0 (_tmp6_);
#line 39 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_g_object_unref0 (_tmp4_);
#line 39 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_g_object_unref0 (_tmp2_);
#line 39 "/home/jens/Source/shotwell/src/AppDirs.vala"
	old_dir = _tmp8_;
#line 42 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp10_ = old_dir;
#line 42 "/home/jens/Source/shotwell/src/AppDirs.vala"
	if (g_file_query_exists (_tmp10_, NULL)) {
#line 363 "AppDirs.c"
		GFile* _tmp11_;
		GFile* _tmp12_;
		GFile* _tmp13_;
#line 42 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp11_ = user_plugin_dir;
#line 42 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp12_ = g_file_get_parent (_tmp11_);
#line 42 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp13_ = _tmp12_;
#line 42 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp9_ = !g_file_query_exists (_tmp13_, NULL);
#line 42 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_g_object_unref0 (_tmp13_);
#line 377 "AppDirs.c"
	} else {
#line 42 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp9_ = FALSE;
#line 381 "AppDirs.c"
	}
#line 42 "/home/jens/Source/shotwell/src/AppDirs.vala"
	if (_tmp9_) {
#line 385 "AppDirs.c"
		{
			GFile* _tmp14_;
			GFile* _tmp15_;
			GFile* _tmp16_;
#line 44 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_tmp14_ = user_plugin_dir;
#line 44 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_tmp15_ = g_file_get_parent (_tmp14_);
#line 44 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_tmp16_ = _tmp15_;
#line 44 "/home/jens/Source/shotwell/src/AppDirs.vala"
			g_file_make_directory_with_parents (_tmp16_, NULL, &_inner_error_);
#line 44 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_g_object_unref0 (_tmp16_);
#line 44 "/home/jens/Source/shotwell/src/AppDirs.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 402 "AppDirs.c"
				goto __catch452_g_error;
			}
		}
		goto __finally452;
		__catch452_g_error:
		{
			GError* err = NULL;
#line 43 "/home/jens/Source/shotwell/src/AppDirs.vala"
			err = _inner_error_;
#line 43 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_inner_error_ = NULL;
#line 43 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_g_error_free0 (err);
#line 416 "AppDirs.c"
		}
		__finally452:
#line 43 "/home/jens/Source/shotwell/src/AppDirs.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 43 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_g_object_unref0 (old_dir);
#line 43 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_g_object_unref0 (user_plugin_dir);
#line 43 "/home/jens/Source/shotwell/src/AppDirs.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 43 "/home/jens/Source/shotwell/src/AppDirs.vala"
			g_clear_error (&_inner_error_);
#line 43 "/home/jens/Source/shotwell/src/AppDirs.vala"
			return;
#line 431 "AppDirs.c"
		}
	}
	{
		GFile* _tmp17_;
		GFile* _tmp18_;
#line 49 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp17_ = old_dir;
#line 49 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp18_ = user_plugin_dir;
#line 49 "/home/jens/Source/shotwell/src/AppDirs.vala"
		g_file_move (_tmp17_, _tmp18_, G_FILE_COPY_NONE, NULL, NULL, NULL, &_inner_error_);
#line 49 "/home/jens/Source/shotwell/src/AppDirs.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 445 "AppDirs.c"
			goto __catch453_g_error;
		}
	}
	goto __finally453;
	__catch453_g_error:
	{
		GError* err = NULL;
#line 48 "/home/jens/Source/shotwell/src/AppDirs.vala"
		err = _inner_error_;
#line 48 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_inner_error_ = NULL;
#line 48 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_g_error_free0 (err);
#line 459 "AppDirs.c"
	}
	__finally453:
#line 48 "/home/jens/Source/shotwell/src/AppDirs.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 48 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_g_object_unref0 (old_dir);
#line 48 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_g_object_unref0 (user_plugin_dir);
#line 48 "/home/jens/Source/shotwell/src/AppDirs.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 48 "/home/jens/Source/shotwell/src/AppDirs.vala"
		g_clear_error (&_inner_error_);
#line 48 "/home/jens/Source/shotwell/src/AppDirs.vala"
		return;
#line 474 "AppDirs.c"
	}
#line 53 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp19_ = app_dirs_get_data_dir ();
#line 53 "/home/jens/Source/shotwell/src/AppDirs.vala"
	new_dir = _tmp19_;
#line 54 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp20_ = app_dirs_get_home_dir ();
#line 54 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp21_ = _tmp20_;
#line 54 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp22_ = g_file_get_child (_tmp21_, ".shotwell");
#line 54 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_g_object_unref0 (old_dir);
#line 54 "/home/jens/Source/shotwell/src/AppDirs.vala"
	old_dir = _tmp22_;
#line 54 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_g_object_unref0 (_tmp21_);
#line 55 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp24_ = new_dir;
#line 55 "/home/jens/Source/shotwell/src/AppDirs.vala"
	if (g_file_query_exists (_tmp24_, NULL)) {
#line 55 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp23_ = TRUE;
#line 498 "AppDirs.c"
	} else {
		GFile* _tmp25_;
#line 55 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp25_ = old_dir;
#line 55 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp23_ = !g_file_query_exists (_tmp25_, NULL);
#line 505 "AppDirs.c"
	}
#line 55 "/home/jens/Source/shotwell/src/AppDirs.vala"
	if (_tmp23_) {
#line 56 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_g_object_unref0 (new_dir);
#line 56 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_g_object_unref0 (old_dir);
#line 56 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_g_object_unref0 (user_plugin_dir);
#line 56 "/home/jens/Source/shotwell/src/AppDirs.vala"
		return;
#line 517 "AppDirs.c"
	}
#line 58 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp26_ = app_dirs_get_cache_dir ();
#line 58 "/home/jens/Source/shotwell/src/AppDirs.vala"
	cache_dir = _tmp26_;
#line 59 "/home/jens/Source/shotwell/src/AppDirs.vala"
	mask = umask ((mode_t) 0077);
#line 60 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp27_ = cache_dir;
#line 60 "/home/jens/Source/shotwell/src/AppDirs.vala"
	if (!g_file_query_exists (_tmp27_, NULL)) {
#line 529 "AppDirs.c"
		{
			GFile* _tmp28_;
#line 62 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_tmp28_ = cache_dir;
#line 62 "/home/jens/Source/shotwell/src/AppDirs.vala"
			g_file_make_directory_with_parents (_tmp28_, NULL, &_inner_error_);
#line 62 "/home/jens/Source/shotwell/src/AppDirs.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 538 "AppDirs.c"
				goto __catch454_g_error;
			}
		}
		goto __finally454;
		__catch454_g_error:
		{
			GError* err = NULL;
			GFile* _tmp29_;
			gchar* _tmp30_;
			gchar* _tmp31_;
			GError* _tmp32_;
			const gchar* _tmp33_;
			gchar* _tmp34_;
			gchar* _tmp35_;
#line 61 "/home/jens/Source/shotwell/src/AppDirs.vala"
			err = _inner_error_;
#line 61 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_inner_error_ = NULL;
#line 64 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_tmp29_ = cache_dir;
#line 64 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_tmp30_ = g_file_get_path (_tmp29_);
#line 64 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_tmp31_ = _tmp30_;
#line 64 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_tmp32_ = err;
#line 64 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_tmp33_ = _tmp32_->message;
#line 64 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_tmp34_ = g_strdup_printf (_ ("Unable to create cache directory %s: %s"), _tmp31_, _tmp33_);
#line 64 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_tmp35_ = _tmp34_;
#line 64 "/home/jens/Source/shotwell/src/AppDirs.vala"
			app_window_panic (_tmp35_);
#line 64 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_g_free0 (_tmp35_);
#line 64 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_g_free0 (_tmp31_);
#line 61 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_g_error_free0 (err);
#line 579 "AppDirs.c"
		}
		__finally454:
#line 61 "/home/jens/Source/shotwell/src/AppDirs.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 61 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_g_object_unref0 (cache_dir);
#line 61 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_g_object_unref0 (new_dir);
#line 61 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_g_object_unref0 (old_dir);
#line 61 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_g_object_unref0 (user_plugin_dir);
#line 61 "/home/jens/Source/shotwell/src/AppDirs.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 61 "/home/jens/Source/shotwell/src/AppDirs.vala"
			g_clear_error (&_inner_error_);
#line 61 "/home/jens/Source/shotwell/src/AppDirs.vala"
			return;
#line 598 "AppDirs.c"
		}
	}
#line 68 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp36_ = old_dir;
#line 68 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp37_ = g_file_get_child (_tmp36_, "thumbs");
#line 68 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp38_ = _tmp37_;
#line 68 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp39_ = g_file_get_path (_tmp38_);
#line 68 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp40_ = _tmp39_;
#line 68 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp41_ = cache_dir;
#line 68 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp42_ = g_file_get_child (_tmp41_, "thumbs");
#line 68 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp43_ = _tmp42_;
#line 68 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp44_ = g_file_get_path (_tmp43_);
#line 68 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp45_ = _tmp44_;
#line 68 "/home/jens/Source/shotwell/src/AppDirs.vala"
	g_rename (_tmp40_, _tmp45_);
#line 68 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_g_free0 (_tmp45_);
#line 68 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_g_object_unref0 (_tmp43_);
#line 68 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_g_free0 (_tmp40_);
#line 68 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_g_object_unref0 (_tmp38_);
#line 70 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp46_ = new_dir;
#line 70 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp47_ = g_file_get_parent (_tmp46_);
#line 70 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp48_ = _tmp47_;
#line 70 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp49_ = !g_file_query_exists (_tmp48_, NULL);
#line 70 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_g_object_unref0 (_tmp48_);
#line 70 "/home/jens/Source/shotwell/src/AppDirs.vala"
	if (_tmp49_) {
#line 643 "AppDirs.c"
		{
			GFile* _tmp50_;
			GFile* _tmp51_;
			GFile* _tmp52_;
#line 72 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_tmp50_ = new_dir;
#line 72 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_tmp51_ = g_file_get_parent (_tmp50_);
#line 72 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_tmp52_ = _tmp51_;
#line 72 "/home/jens/Source/shotwell/src/AppDirs.vala"
			g_file_make_directory_with_parents (_tmp52_, NULL, &_inner_error_);
#line 72 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_g_object_unref0 (_tmp52_);
#line 72 "/home/jens/Source/shotwell/src/AppDirs.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 660 "AppDirs.c"
				goto __catch455_g_error;
			}
		}
		goto __finally455;
		__catch455_g_error:
		{
			GError* err = NULL;
			GFile* _tmp53_;
			GFile* _tmp54_;
			GFile* _tmp55_;
			gchar* _tmp56_;
			gchar* _tmp57_;
			GError* _tmp58_;
			const gchar* _tmp59_;
			gchar* _tmp60_;
			gchar* _tmp61_;
#line 71 "/home/jens/Source/shotwell/src/AppDirs.vala"
			err = _inner_error_;
#line 71 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_inner_error_ = NULL;
#line 74 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_tmp53_ = new_dir;
#line 74 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_tmp54_ = g_file_get_parent (_tmp53_);
#line 74 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_tmp55_ = _tmp54_;
#line 74 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_tmp56_ = g_file_get_path (_tmp55_);
#line 74 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_tmp57_ = _tmp56_;
#line 74 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_tmp58_ = err;
#line 74 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_tmp59_ = _tmp58_->message;
#line 74 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_tmp60_ = g_strdup_printf (_ ("Unable to create data directory %s: %s"), _tmp57_, _tmp59_);
#line 74 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_tmp61_ = _tmp60_;
#line 74 "/home/jens/Source/shotwell/src/AppDirs.vala"
			app_window_panic (_tmp61_);
#line 74 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_g_free0 (_tmp61_);
#line 74 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_g_free0 (_tmp57_);
#line 74 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_g_object_unref0 (_tmp55_);
#line 71 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_g_error_free0 (err);
#line 709 "AppDirs.c"
		}
		__finally455:
#line 71 "/home/jens/Source/shotwell/src/AppDirs.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 71 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_g_object_unref0 (cache_dir);
#line 71 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_g_object_unref0 (new_dir);
#line 71 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_g_object_unref0 (old_dir);
#line 71 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_g_object_unref0 (user_plugin_dir);
#line 71 "/home/jens/Source/shotwell/src/AppDirs.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 71 "/home/jens/Source/shotwell/src/AppDirs.vala"
			g_clear_error (&_inner_error_);
#line 71 "/home/jens/Source/shotwell/src/AppDirs.vala"
			return;
#line 728 "AppDirs.c"
		}
	}
#line 78 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp62_ = old_dir;
#line 78 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp63_ = g_file_get_path (_tmp62_);
#line 78 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp64_ = _tmp63_;
#line 78 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp65_ = new_dir;
#line 78 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp66_ = g_file_get_path (_tmp65_);
#line 78 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp67_ = _tmp66_;
#line 78 "/home/jens/Source/shotwell/src/AppDirs.vala"
	g_rename (_tmp64_, _tmp67_);
#line 78 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_g_free0 (_tmp67_);
#line 78 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_g_free0 (_tmp64_);
#line 79 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp68_ = new_dir;
#line 79 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp69_ = g_file_get_path (_tmp68_);
#line 79 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp70_ = _tmp69_;
#line 79 "/home/jens/Source/shotwell/src/AppDirs.vala"
	g_chmod (_tmp70_, 0700);
#line 79 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_g_free0 (_tmp70_);
#line 81 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp71_ = mask;
#line 81 "/home/jens/Source/shotwell/src/AppDirs.vala"
	umask (_tmp71_);
#line 36 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_g_object_unref0 (cache_dir);
#line 36 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_g_object_unref0 (new_dir);
#line 36 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_g_object_unref0 (old_dir);
#line 36 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_g_object_unref0 (user_plugin_dir);
#line 771 "AppDirs.c"
}


void
app_dirs_set_data_dir (const gchar* user_data_dir)
{
	GFile* _tmp0_;
	gchar* path = NULL;
	gchar* _tmp1_;
	const gchar* _tmp2_;
	GFile* _tmp9_;
	gchar* _tmp10_;
	gchar* _tmp11_;
#line 85 "/home/jens/Source/shotwell/src/AppDirs.vala"
	g_return_if_fail (user_data_dir != NULL);
#line 85 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_vala_return_if_fail (!is_string_empty (user_data_dir), "!is_string_empty(user_data_dir)");
#line 86 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp0_ = app_dirs_data_dir;
#line 86 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_vala_assert (_tmp0_ == NULL, "data_dir == null");
#line 89 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp1_ = strip_pretty_path (user_data_dir);
#line 89 "/home/jens/Source/shotwell/src/AppDirs.vala"
	path = _tmp1_;
#line 90 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp2_ = path;
#line 90 "/home/jens/Source/shotwell/src/AppDirs.vala"
	if (!g_path_is_absolute (_tmp2_)) {
#line 801 "AppDirs.c"
		GFile* _tmp3_;
		GFile* _tmp4_;
		const gchar* _tmp5_;
		GFile* _tmp6_;
#line 91 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp3_ = app_dirs_get_home_dir ();
#line 91 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp4_ = _tmp3_;
#line 91 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp5_ = path;
#line 91 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp6_ = g_file_get_child (_tmp4_, _tmp5_);
#line 91 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_g_object_unref0 (app_dirs_data_dir);
#line 91 "/home/jens/Source/shotwell/src/AppDirs.vala"
		app_dirs_data_dir = _tmp6_;
#line 91 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_g_object_unref0 (_tmp4_);
#line 820 "AppDirs.c"
	} else {
		const gchar* _tmp7_;
		GFile* _tmp8_;
#line 93 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp7_ = path;
#line 93 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp8_ = g_file_new_for_path (_tmp7_);
#line 93 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_g_object_unref0 (app_dirs_data_dir);
#line 93 "/home/jens/Source/shotwell/src/AppDirs.vala"
		app_dirs_data_dir = _tmp8_;
#line 832 "AppDirs.c"
	}
#line 95 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp9_ = app_dirs_data_dir;
#line 95 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp10_ = g_file_get_path (_tmp9_);
#line 95 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp11_ = _tmp10_;
#line 95 "/home/jens/Source/shotwell/src/AppDirs.vala"
	g_message ("AppDirs.vala:95: Setting private data directory to %s", _tmp11_);
#line 95 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_g_free0 (_tmp11_);
#line 85 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_g_free0 (path);
#line 846 "AppDirs.c"
}


void
app_dirs_verify_data_dir (void)
{
	GFile* data_dir = NULL;
	GFile* _tmp0_;
	GError * _inner_error_ = NULL;
#line 99 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp0_ = app_dirs_get_data_dir ();
#line 99 "/home/jens/Source/shotwell/src/AppDirs.vala"
	data_dir = _tmp0_;
#line 860 "AppDirs.c"
	{
		GFile* _tmp1_;
#line 101 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp1_ = data_dir;
#line 101 "/home/jens/Source/shotwell/src/AppDirs.vala"
		if (!g_file_query_exists (_tmp1_, NULL)) {
#line 867 "AppDirs.c"
			GFile* _tmp2_;
#line 102 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_tmp2_ = data_dir;
#line 102 "/home/jens/Source/shotwell/src/AppDirs.vala"
			g_file_make_directory_with_parents (_tmp2_, NULL, &_inner_error_);
#line 102 "/home/jens/Source/shotwell/src/AppDirs.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 875 "AppDirs.c"
				goto __catch456_g_error;
			}
		}
	}
	goto __finally456;
	__catch456_g_error:
	{
		GError* err = NULL;
		GFile* _tmp3_;
		gchar* _tmp4_;
		gchar* _tmp5_;
		GError* _tmp6_;
		const gchar* _tmp7_;
		gchar* _tmp8_;
		gchar* _tmp9_;
#line 100 "/home/jens/Source/shotwell/src/AppDirs.vala"
		err = _inner_error_;
#line 100 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_inner_error_ = NULL;
#line 104 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp3_ = data_dir;
#line 104 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp4_ = g_file_get_path (_tmp3_);
#line 104 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp5_ = _tmp4_;
#line 104 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp6_ = err;
#line 104 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp7_ = _tmp6_->message;
#line 104 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp8_ = g_strdup_printf (_ ("Unable to create data directory %s: %s"), _tmp5_, _tmp7_);
#line 104 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp9_ = _tmp8_;
#line 104 "/home/jens/Source/shotwell/src/AppDirs.vala"
		app_window_panic (_tmp9_);
#line 104 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_g_free0 (_tmp9_);
#line 104 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_g_free0 (_tmp5_);
#line 100 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_g_error_free0 (err);
#line 917 "AppDirs.c"
	}
	__finally456:
#line 100 "/home/jens/Source/shotwell/src/AppDirs.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 100 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_g_object_unref0 (data_dir);
#line 100 "/home/jens/Source/shotwell/src/AppDirs.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 100 "/home/jens/Source/shotwell/src/AppDirs.vala"
		g_clear_error (&_inner_error_);
#line 100 "/home/jens/Source/shotwell/src/AppDirs.vala"
		return;
#line 930 "AppDirs.c"
	}
#line 98 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_g_object_unref0 (data_dir);
#line 934 "AppDirs.c"
}


void
app_dirs_verify_cache_dir (void)
{
	GFile* cache_dir = NULL;
	GFile* _tmp0_;
	GError * _inner_error_ = NULL;
#line 110 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp0_ = app_dirs_get_cache_dir ();
#line 110 "/home/jens/Source/shotwell/src/AppDirs.vala"
	cache_dir = _tmp0_;
#line 948 "AppDirs.c"
	{
		GFile* _tmp1_;
#line 112 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp1_ = cache_dir;
#line 112 "/home/jens/Source/shotwell/src/AppDirs.vala"
		if (!g_file_query_exists (_tmp1_, NULL)) {
#line 955 "AppDirs.c"
			GFile* _tmp2_;
#line 113 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_tmp2_ = cache_dir;
#line 113 "/home/jens/Source/shotwell/src/AppDirs.vala"
			g_file_make_directory_with_parents (_tmp2_, NULL, &_inner_error_);
#line 113 "/home/jens/Source/shotwell/src/AppDirs.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 963 "AppDirs.c"
				goto __catch457_g_error;
			}
		}
	}
	goto __finally457;
	__catch457_g_error:
	{
		GError* err = NULL;
		GFile* _tmp3_;
		gchar* _tmp4_;
		gchar* _tmp5_;
		GError* _tmp6_;
		const gchar* _tmp7_;
		gchar* _tmp8_;
		gchar* _tmp9_;
#line 111 "/home/jens/Source/shotwell/src/AppDirs.vala"
		err = _inner_error_;
#line 111 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_inner_error_ = NULL;
#line 115 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp3_ = cache_dir;
#line 115 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp4_ = g_file_get_path (_tmp3_);
#line 115 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp5_ = _tmp4_;
#line 115 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp6_ = err;
#line 115 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp7_ = _tmp6_->message;
#line 115 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp8_ = g_strdup_printf (_ ("Unable to create cache directory %s: %s"), _tmp5_, _tmp7_);
#line 115 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp9_ = _tmp8_;
#line 115 "/home/jens/Source/shotwell/src/AppDirs.vala"
		app_window_panic (_tmp9_);
#line 115 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_g_free0 (_tmp9_);
#line 115 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_g_free0 (_tmp5_);
#line 111 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_g_error_free0 (err);
#line 1005 "AppDirs.c"
	}
	__finally457:
#line 111 "/home/jens/Source/shotwell/src/AppDirs.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 111 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_g_object_unref0 (cache_dir);
#line 111 "/home/jens/Source/shotwell/src/AppDirs.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 111 "/home/jens/Source/shotwell/src/AppDirs.vala"
		g_clear_error (&_inner_error_);
#line 111 "/home/jens/Source/shotwell/src/AppDirs.vala"
		return;
#line 1018 "AppDirs.c"
	}
#line 109 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_g_object_unref0 (cache_dir);
#line 1022 "AppDirs.c"
}


/**
     * @brief Returns the build directory if not installed yet, or a path
     * to where any helper applets we need will live if installed.
     */
GFile*
app_dirs_get_libexec_dir (void)
{
	GFile* result = NULL;
	GFile* _tmp0_;
	GFile* _tmp6_;
	GFile* _tmp7_;
#line 125 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp0_ = app_dirs_libexec_dir;
#line 125 "/home/jens/Source/shotwell/src/AppDirs.vala"
	if (_tmp0_ == NULL) {
#line 1041 "AppDirs.c"
		GFile* _tmp1_;
		GFile* _tmp2_;
		gboolean _tmp3_;
#line 126 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp1_ = app_dirs_get_install_dir ();
#line 126 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp2_ = _tmp1_;
#line 126 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp3_ = _tmp2_ == NULL;
#line 126 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_g_object_unref0 (_tmp2_);
#line 126 "/home/jens/Source/shotwell/src/AppDirs.vala"
		if (_tmp3_) {
#line 1055 "AppDirs.c"
			GFile* _tmp4_;
#line 128 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_tmp4_ = app_dirs_get_exec_dir ();
#line 128 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_g_object_unref0 (app_dirs_libexec_dir);
#line 128 "/home/jens/Source/shotwell/src/AppDirs.vala"
			app_dirs_libexec_dir = _tmp4_;
#line 1063 "AppDirs.c"
		} else {
			GFile* _tmp5_;
#line 130 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_tmp5_ = g_file_new_for_path (RESOURCES_LIBEXECDIR);
#line 130 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_g_object_unref0 (app_dirs_libexec_dir);
#line 130 "/home/jens/Source/shotwell/src/AppDirs.vala"
			app_dirs_libexec_dir = _tmp5_;
#line 1072 "AppDirs.c"
		}
	}
#line 134 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp6_ = app_dirs_libexec_dir;
#line 134 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp7_ = _g_object_ref0 (_tmp6_);
#line 134 "/home/jens/Source/shotwell/src/AppDirs.vala"
	result = _tmp7_;
#line 134 "/home/jens/Source/shotwell/src/AppDirs.vala"
	return result;
#line 1083 "AppDirs.c"
}


GFile*
app_dirs_get_install_dir (void)
{
	GFile* result = NULL;
	GFile* _tmp0_;
	GFile* _tmp1_;
#line 139 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp0_ = app_dirs_exec_dir;
#line 139 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp1_ = get_sys_install_dir (_tmp0_);
#line 139 "/home/jens/Source/shotwell/src/AppDirs.vala"
	result = _tmp1_;
#line 139 "/home/jens/Source/shotwell/src/AppDirs.vala"
	return result;
#line 1101 "AppDirs.c"
}


GFile*
app_dirs_get_data_dir (void)
{
	GFile* result = NULL;
	GFile* _tmp0_ = NULL;
	GFile* _tmp1_;
#line 143 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp1_ = app_dirs_data_dir;
#line 143 "/home/jens/Source/shotwell/src/AppDirs.vala"
	if (_tmp1_ == NULL) {
#line 1115 "AppDirs.c"
		const gchar* _tmp2_;
		GFile* _tmp3_;
		GFile* _tmp4_;
		GFile* _tmp5_;
#line 143 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp2_ = g_get_user_data_dir ();
#line 143 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp3_ = g_file_new_for_path (_tmp2_);
#line 143 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp4_ = _tmp3_;
#line 143 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp5_ = g_file_get_child (_tmp4_, APP_DIRS_DEFAULT_DATA_DIR);
#line 143 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_g_object_unref0 (_tmp0_);
#line 143 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp0_ = _tmp5_;
#line 143 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_g_object_unref0 (_tmp4_);
#line 1134 "AppDirs.c"
	} else {
		GFile* _tmp6_;
		GFile* _tmp7_;
#line 143 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp6_ = app_dirs_data_dir;
#line 143 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp7_ = _g_object_ref0 (_tmp6_);
#line 143 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_g_object_unref0 (_tmp0_);
#line 143 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp0_ = _tmp7_;
#line 1146 "AppDirs.c"
	}
#line 143 "/home/jens/Source/shotwell/src/AppDirs.vala"
	result = _tmp0_;
#line 143 "/home/jens/Source/shotwell/src/AppDirs.vala"
	return result;
#line 1152 "AppDirs.c"
}


GFile*
app_dirs_get_import_dir (void)
{
	GFile* result = NULL;
	gchar* path = NULL;
	ConfigFacade* _tmp0_;
	ConfigFacade* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	const gchar* _tmp4_;
	const gchar* _tmp15_;
	gchar* _tmp16_;
	const gchar* _tmp17_;
	GFile* _tmp20_;
	GFile* _tmp21_;
	GFile* _tmp22_;
	GFile* _tmp23_;
#line 149 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp0_ = config_facade_get_instance ();
#line 149 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp1_ = _tmp0_;
#line 149 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp2_ = configuration_facade_get_import_dir (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 149 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp3_ = _tmp2_;
#line 149 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_g_object_unref0 (_tmp1_);
#line 149 "/home/jens/Source/shotwell/src/AppDirs.vala"
	path = _tmp3_;
#line 150 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp4_ = path;
#line 150 "/home/jens/Source/shotwell/src/AppDirs.vala"
	if (!is_string_empty (_tmp4_)) {
#line 1189 "AppDirs.c"
		const gchar* _tmp5_;
		gchar* _tmp6_;
		const gchar* _tmp7_;
		const gchar* _tmp13_;
		GFile* _tmp14_;
#line 152 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp5_ = path;
#line 152 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp6_ = strip_pretty_path (_tmp5_);
#line 152 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_g_free0 (path);
#line 152 "/home/jens/Source/shotwell/src/AppDirs.vala"
		path = _tmp6_;
#line 155 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp7_ = path;
#line 155 "/home/jens/Source/shotwell/src/AppDirs.vala"
		if (!g_path_is_absolute (_tmp7_)) {
#line 1207 "AppDirs.c"
			GFile* _tmp8_;
			GFile* _tmp9_;
			const gchar* _tmp10_;
			GFile* _tmp11_;
			GFile* _tmp12_;
#line 156 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_tmp8_ = app_dirs_get_home_dir ();
#line 156 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_tmp9_ = _tmp8_;
#line 156 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_tmp10_ = path;
#line 156 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_tmp11_ = g_file_get_child (_tmp9_, _tmp10_);
#line 156 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_tmp12_ = _tmp11_;
#line 156 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_g_object_unref0 (_tmp9_);
#line 156 "/home/jens/Source/shotwell/src/AppDirs.vala"
			result = _tmp12_;
#line 156 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_g_free0 (path);
#line 156 "/home/jens/Source/shotwell/src/AppDirs.vala"
			return result;
#line 1231 "AppDirs.c"
		}
#line 159 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp13_ = path;
#line 159 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp14_ = g_file_new_for_path (_tmp13_);
#line 159 "/home/jens/Source/shotwell/src/AppDirs.vala"
		result = _tmp14_;
#line 159 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_g_free0 (path);
#line 159 "/home/jens/Source/shotwell/src/AppDirs.vala"
		return result;
#line 1243 "AppDirs.c"
	}
#line 163 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp15_ = g_get_user_special_dir (G_USER_DIRECTORY_PICTURES);
#line 163 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp16_ = g_strdup (_tmp15_);
#line 163 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_g_free0 (path);
#line 163 "/home/jens/Source/shotwell/src/AppDirs.vala"
	path = _tmp16_;
#line 164 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp17_ = path;
#line 164 "/home/jens/Source/shotwell/src/AppDirs.vala"
	if (!is_string_empty (_tmp17_)) {
#line 1257 "AppDirs.c"
		const gchar* _tmp18_;
		GFile* _tmp19_;
#line 165 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp18_ = path;
#line 165 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp19_ = g_file_new_for_path (_tmp18_);
#line 165 "/home/jens/Source/shotwell/src/AppDirs.vala"
		result = _tmp19_;
#line 165 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_g_free0 (path);
#line 165 "/home/jens/Source/shotwell/src/AppDirs.vala"
		return result;
#line 1270 "AppDirs.c"
	}
#line 168 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp20_ = app_dirs_get_home_dir ();
#line 168 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp21_ = _tmp20_;
#line 168 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp22_ = g_file_get_child (_tmp21_, _ ("Pictures"));
#line 168 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp23_ = _tmp22_;
#line 168 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_g_object_unref0 (_tmp21_);
#line 168 "/home/jens/Source/shotwell/src/AppDirs.vala"
	result = _tmp23_;
#line 168 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_g_free0 (path);
#line 168 "/home/jens/Source/shotwell/src/AppDirs.vala"
	return result;
#line 1288 "AppDirs.c"
}


GFile*
app_dirs_get_baked_import_dir (time_t tm)
{
	GFile* result = NULL;
	gchar* pattern = NULL;
	ConfigFacade* _tmp0_;
	ConfigFacade* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	const gchar* _tmp4_;
	const gchar* _tmp8_;
	GDateTime* date = NULL;
	GDateTime* _tmp10_;
	GFile* _tmp11_;
	GFile* _tmp12_;
	gchar* _tmp13_;
	gchar* _tmp14_;
	gchar* _tmp15_;
	gchar* _tmp16_;
	const gchar* _tmp17_;
	gchar* _tmp18_;
	gchar* _tmp19_;
	gchar* _tmp20_;
	gchar* _tmp21_;
	GFile* _tmp22_;
	GFile* _tmp23_;
#line 173 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp0_ = config_facade_get_instance ();
#line 173 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp1_ = _tmp0_;
#line 173 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp2_ = configuration_facade_get_directory_pattern (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 173 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp3_ = _tmp2_;
#line 173 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_g_object_unref0 (_tmp1_);
#line 173 "/home/jens/Source/shotwell/src/AppDirs.vala"
	pattern = _tmp3_;
#line 174 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp4_ = pattern;
#line 174 "/home/jens/Source/shotwell/src/AppDirs.vala"
	if (is_string_empty (_tmp4_)) {
#line 1334 "AppDirs.c"
		ConfigFacade* _tmp5_;
		ConfigFacade* _tmp6_;
		gchar* _tmp7_;
#line 175 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp5_ = config_facade_get_instance ();
#line 175 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp6_ = _tmp5_;
#line 175 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp7_ = configuration_facade_get_directory_pattern_custom (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 175 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_g_free0 (pattern);
#line 175 "/home/jens/Source/shotwell/src/AppDirs.vala"
		pattern = _tmp7_;
#line 175 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_g_object_unref0 (_tmp6_);
#line 1350 "AppDirs.c"
	}
#line 176 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp8_ = pattern;
#line 176 "/home/jens/Source/shotwell/src/AppDirs.vala"
	if (is_string_empty (_tmp8_)) {
#line 1356 "AppDirs.c"
		gchar* _tmp9_;
#line 177 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp9_ = g_strdup ("%Y" G_DIR_SEPARATOR_S "%m" G_DIR_SEPARATOR_S "%d");
#line 177 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_g_free0 (pattern);
#line 177 "/home/jens/Source/shotwell/src/AppDirs.vala"
		pattern = _tmp9_;
#line 1364 "AppDirs.c"
	}
#line 179 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp10_ = g_date_time_new_from_unix_local ((gint64) tm);
#line 179 "/home/jens/Source/shotwell/src/AppDirs.vala"
	date = _tmp10_;
#line 180 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp11_ = app_dirs_get_import_dir ();
#line 180 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp12_ = _tmp11_;
#line 180 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp13_ = g_file_get_path (_tmp12_);
#line 180 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp14_ = _tmp13_;
#line 180 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp15_ = g_strconcat (_tmp14_, G_DIR_SEPARATOR_S, NULL);
#line 180 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp16_ = _tmp15_;
#line 180 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp17_ = pattern;
#line 180 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp18_ = g_date_time_format (date, _tmp17_);
#line 180 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp19_ = _tmp18_;
#line 180 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp20_ = g_strconcat (_tmp16_, _tmp19_, NULL);
#line 180 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp21_ = _tmp20_;
#line 180 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp22_ = g_file_new_for_path (_tmp21_);
#line 180 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp23_ = _tmp22_;
#line 180 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_g_free0 (_tmp21_);
#line 180 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_g_free0 (_tmp19_);
#line 180 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_g_free0 (_tmp16_);
#line 180 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_g_free0 (_tmp14_);
#line 180 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_g_object_unref0 (_tmp12_);
#line 180 "/home/jens/Source/shotwell/src/AppDirs.vala"
	result = _tmp23_;
#line 180 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_g_date_time_unref0 (date);
#line 180 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_g_free0 (pattern);
#line 180 "/home/jens/Source/shotwell/src/AppDirs.vala"
	return result;
#line 1414 "AppDirs.c"
}


gboolean
app_dirs_is_in_import_dir (GFile* file)
{
	gboolean result = FALSE;
	GFile* import_dir = NULL;
	GFile* _tmp0_;
	gboolean _tmp1_ = FALSE;
	GFile* _tmp2_;
#line 184 "/home/jens/Source/shotwell/src/AppDirs.vala"
	g_return_val_if_fail (G_IS_FILE (file), FALSE);
#line 185 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp0_ = app_dirs_get_import_dir ();
#line 185 "/home/jens/Source/shotwell/src/AppDirs.vala"
	import_dir = _tmp0_;
#line 187 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp2_ = import_dir;
#line 187 "/home/jens/Source/shotwell/src/AppDirs.vala"
	if (g_file_has_prefix (file, _tmp2_)) {
#line 187 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp1_ = TRUE;
#line 1438 "AppDirs.c"
	} else {
		GFile* _tmp3_;
#line 187 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp3_ = import_dir;
#line 187 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp1_ = g_file_equal (file, _tmp3_);
#line 1445 "AppDirs.c"
	}
#line 187 "/home/jens/Source/shotwell/src/AppDirs.vala"
	result = _tmp1_;
#line 187 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_g_object_unref0 (import_dir);
#line 187 "/home/jens/Source/shotwell/src/AppDirs.vala"
	return result;
#line 1453 "AppDirs.c"
}


void
app_dirs_set_import_dir (const gchar* path)
{
	ConfigFacade* _tmp0_;
	ConfigFacade* _tmp1_;
#line 190 "/home/jens/Source/shotwell/src/AppDirs.vala"
	g_return_if_fail (path != NULL);
#line 191 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp0_ = config_facade_get_instance ();
#line 191 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp1_ = _tmp0_;
#line 191 "/home/jens/Source/shotwell/src/AppDirs.vala"
	configuration_facade_set_import_dir (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), path);
#line 191 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_g_object_unref0 (_tmp1_);
#line 1472 "AppDirs.c"
}


GFile*
app_dirs_get_exec_dir (void)
{
	GFile* result = NULL;
	GFile* _tmp0_;
	GFile* _tmp1_;
#line 195 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp0_ = app_dirs_exec_dir;
#line 195 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 195 "/home/jens/Source/shotwell/src/AppDirs.vala"
	result = _tmp1_;
#line 195 "/home/jens/Source/shotwell/src/AppDirs.vala"
	return result;
#line 1490 "AppDirs.c"
}


GFile*
app_dirs_get_temp_dir (void)
{
	GFile* result = NULL;
	GFile* _tmp0_;
	GFile* _tmp15_;
	GFile* _tmp16_;
	GError * _inner_error_ = NULL;
#line 199 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp0_ = app_dirs_tmp_dir;
#line 199 "/home/jens/Source/shotwell/src/AppDirs.vala"
	if (_tmp0_ == NULL) {
#line 1506 "AppDirs.c"
		const gchar* _tmp1_;
		gchar* _tmp2_;
		gchar* _tmp3_;
		gchar* _tmp4_;
		GFile* _tmp5_;
#line 200 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp1_ = g_get_tmp_dir ();
#line 200 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp2_ = g_strconcat (_tmp1_, "/shotwell-XXXXXX", NULL);
#line 200 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp3_ = mkdtemp (_tmp2_);
#line 200 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp4_ = _tmp3_;
#line 200 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp5_ = g_file_new_for_path (_tmp4_);
#line 200 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_g_object_unref0 (app_dirs_tmp_dir);
#line 200 "/home/jens/Source/shotwell/src/AppDirs.vala"
		app_dirs_tmp_dir = _tmp5_;
#line 200 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_g_free0 (_tmp4_);
#line 1528 "AppDirs.c"
		{
			GFile* _tmp6_;
#line 203 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_tmp6_ = app_dirs_tmp_dir;
#line 203 "/home/jens/Source/shotwell/src/AppDirs.vala"
			if (!g_file_query_exists (_tmp6_, NULL)) {
#line 1535 "AppDirs.c"
				GFile* _tmp7_;
#line 204 "/home/jens/Source/shotwell/src/AppDirs.vala"
				_tmp7_ = app_dirs_tmp_dir;
#line 204 "/home/jens/Source/shotwell/src/AppDirs.vala"
				g_file_make_directory_with_parents (_tmp7_, NULL, &_inner_error_);
#line 204 "/home/jens/Source/shotwell/src/AppDirs.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1543 "AppDirs.c"
					goto __catch458_g_error;
				}
			}
		}
		goto __finally458;
		__catch458_g_error:
		{
			GError* err = NULL;
			GFile* _tmp8_;
			gchar* _tmp9_;
			gchar* _tmp10_;
			GError* _tmp11_;
			const gchar* _tmp12_;
			gchar* _tmp13_;
			gchar* _tmp14_;
#line 202 "/home/jens/Source/shotwell/src/AppDirs.vala"
			err = _inner_error_;
#line 202 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_inner_error_ = NULL;
#line 206 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_tmp8_ = app_dirs_tmp_dir;
#line 206 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_tmp9_ = g_file_get_path (_tmp8_);
#line 206 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_tmp10_ = _tmp9_;
#line 206 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_tmp11_ = err;
#line 206 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_tmp12_ = _tmp11_->message;
#line 206 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_tmp13_ = g_strdup_printf (_ ("Unable to create temporary directory %s: %s"), _tmp10_, _tmp12_);
#line 206 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_tmp14_ = _tmp13_;
#line 206 "/home/jens/Source/shotwell/src/AppDirs.vala"
			app_window_panic (_tmp14_);
#line 206 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_g_free0 (_tmp14_);
#line 206 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_g_free0 (_tmp10_);
#line 202 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_g_error_free0 (err);
#line 1585 "AppDirs.c"
		}
		__finally458:
#line 202 "/home/jens/Source/shotwell/src/AppDirs.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 202 "/home/jens/Source/shotwell/src/AppDirs.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 202 "/home/jens/Source/shotwell/src/AppDirs.vala"
			g_clear_error (&_inner_error_);
#line 202 "/home/jens/Source/shotwell/src/AppDirs.vala"
			return NULL;
#line 1596 "AppDirs.c"
		}
	}
#line 211 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp15_ = app_dirs_tmp_dir;
#line 211 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp16_ = _g_object_ref0 (_tmp15_);
#line 211 "/home/jens/Source/shotwell/src/AppDirs.vala"
	result = _tmp16_;
#line 211 "/home/jens/Source/shotwell/src/AppDirs.vala"
	return result;
#line 1607 "AppDirs.c"
}


GFile*
app_dirs_get_data_subdir (const gchar* name,
                          const gchar* subname)
{
	GFile* result = NULL;
	GFile* subdir = NULL;
	GFile* _tmp0_;
	GFile* _tmp1_;
	GFile* _tmp2_;
	GFile* _tmp3_;
	GError * _inner_error_ = NULL;
#line 214 "/home/jens/Source/shotwell/src/AppDirs.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 215 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp0_ = app_dirs_get_data_dir ();
#line 215 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp1_ = _tmp0_;
#line 215 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp2_ = g_file_get_child (_tmp1_, name);
#line 215 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp3_ = _tmp2_;
#line 215 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_g_object_unref0 (_tmp1_);
#line 215 "/home/jens/Source/shotwell/src/AppDirs.vala"
	subdir = _tmp3_;
#line 216 "/home/jens/Source/shotwell/src/AppDirs.vala"
	if (subname != NULL) {
#line 1638 "AppDirs.c"
		GFile* _tmp4_;
		GFile* _tmp5_;
#line 217 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp4_ = subdir;
#line 217 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp5_ = g_file_get_child (_tmp4_, subname);
#line 217 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_g_object_unref0 (subdir);
#line 217 "/home/jens/Source/shotwell/src/AppDirs.vala"
		subdir = _tmp5_;
#line 1649 "AppDirs.c"
	}
	{
		GFile* _tmp6_;
#line 220 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp6_ = subdir;
#line 220 "/home/jens/Source/shotwell/src/AppDirs.vala"
		if (!g_file_query_exists (_tmp6_, NULL)) {
#line 1657 "AppDirs.c"
			GFile* _tmp7_;
#line 221 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_tmp7_ = subdir;
#line 221 "/home/jens/Source/shotwell/src/AppDirs.vala"
			g_file_make_directory_with_parents (_tmp7_, NULL, &_inner_error_);
#line 221 "/home/jens/Source/shotwell/src/AppDirs.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1665 "AppDirs.c"
				goto __catch459_g_error;
			}
		}
	}
	goto __finally459;
	__catch459_g_error:
	{
		GError* err = NULL;
		GFile* _tmp8_;
		gchar* _tmp9_;
		gchar* _tmp10_;
		GError* _tmp11_;
		const gchar* _tmp12_;
		gchar* _tmp13_;
		gchar* _tmp14_;
#line 219 "/home/jens/Source/shotwell/src/AppDirs.vala"
		err = _inner_error_;
#line 219 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_inner_error_ = NULL;
#line 223 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp8_ = subdir;
#line 223 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp9_ = g_file_get_path (_tmp8_);
#line 223 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp10_ = _tmp9_;
#line 223 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp11_ = err;
#line 223 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp12_ = _tmp11_->message;
#line 223 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp13_ = g_strdup_printf (_ ("Unable to create data subdirectory %s: %s"), _tmp10_, _tmp12_);
#line 223 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp14_ = _tmp13_;
#line 223 "/home/jens/Source/shotwell/src/AppDirs.vala"
		app_window_panic (_tmp14_);
#line 223 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_g_free0 (_tmp14_);
#line 223 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_g_free0 (_tmp10_);
#line 219 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_g_error_free0 (err);
#line 1707 "AppDirs.c"
	}
	__finally459:
#line 219 "/home/jens/Source/shotwell/src/AppDirs.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 219 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_g_object_unref0 (subdir);
#line 219 "/home/jens/Source/shotwell/src/AppDirs.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 219 "/home/jens/Source/shotwell/src/AppDirs.vala"
		g_clear_error (&_inner_error_);
#line 219 "/home/jens/Source/shotwell/src/AppDirs.vala"
		return NULL;
#line 1720 "AppDirs.c"
	}
#line 227 "/home/jens/Source/shotwell/src/AppDirs.vala"
	result = subdir;
#line 227 "/home/jens/Source/shotwell/src/AppDirs.vala"
	return result;
#line 1726 "AppDirs.c"
}


void
app_dirs_ensure_writable (GFile* dir)
{
	GError * _inner_error_ = NULL;
#line 230 "/home/jens/Source/shotwell/src/AppDirs.vala"
	g_return_if_fail (G_IS_FILE (dir));
#line 231 "/home/jens/Source/shotwell/src/AppDirs.vala"
	if (g_file_query_exists (dir, NULL)) {
#line 1738 "AppDirs.c"
		{
			GFileInfo* info = NULL;
			GFileInfo* _tmp0_;
			guint32 mode = 0U;
			GFileInfo* _tmp1_;
			gboolean _tmp2_ = FALSE;
			guint32 _tmp3_;
#line 233 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_tmp0_ = g_file_query_info (dir, G_FILE_ATTRIBUTE_UNIX_MODE, G_FILE_QUERY_INFO_NONE, NULL, &_inner_error_);
#line 233 "/home/jens/Source/shotwell/src/AppDirs.vala"
			info = _tmp0_;
#line 233 "/home/jens/Source/shotwell/src/AppDirs.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1752 "AppDirs.c"
				goto __catch460_g_error;
			}
#line 234 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_tmp1_ = info;
#line 234 "/home/jens/Source/shotwell/src/AppDirs.vala"
			mode = g_file_info_get_attribute_uint32 (_tmp1_, G_FILE_ATTRIBUTE_UNIX_MODE) | 0700;
#line 235 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_tmp3_ = mode;
#line 235 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_tmp2_ = g_file_set_attribute_uint32 (dir, G_FILE_ATTRIBUTE_UNIX_MODE, _tmp3_, G_FILE_QUERY_INFO_NONE, NULL, &_inner_error_);
#line 235 "/home/jens/Source/shotwell/src/AppDirs.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 235 "/home/jens/Source/shotwell/src/AppDirs.vala"
				_g_object_unref0 (info);
#line 1767 "AppDirs.c"
				goto __catch460_g_error;
			}
#line 235 "/home/jens/Source/shotwell/src/AppDirs.vala"
			if (!_tmp2_) {
#line 1772 "AppDirs.c"
				gchar* _tmp4_;
				gchar* _tmp5_;
				gchar* _tmp6_;
				gchar* _tmp7_;
#line 236 "/home/jens/Source/shotwell/src/AppDirs.vala"
				_tmp4_ = g_file_get_path (dir);
#line 236 "/home/jens/Source/shotwell/src/AppDirs.vala"
				_tmp5_ = _tmp4_;
#line 236 "/home/jens/Source/shotwell/src/AppDirs.vala"
				_tmp6_ = g_strdup_printf (_ ("Could not make directory %s writable"), _tmp5_);
#line 236 "/home/jens/Source/shotwell/src/AppDirs.vala"
				_tmp7_ = _tmp6_;
#line 236 "/home/jens/Source/shotwell/src/AppDirs.vala"
				app_window_panic (_tmp7_);
#line 236 "/home/jens/Source/shotwell/src/AppDirs.vala"
				_g_free0 (_tmp7_);
#line 236 "/home/jens/Source/shotwell/src/AppDirs.vala"
				_g_free0 (_tmp5_);
#line 1791 "AppDirs.c"
			}
#line 232 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_g_object_unref0 (info);
#line 1795 "AppDirs.c"
		}
		goto __finally460;
		__catch460_g_error:
		{
			GError* err = NULL;
			gchar* _tmp8_;
			gchar* _tmp9_;
			GError* _tmp10_;
			const gchar* _tmp11_;
			gchar* _tmp12_;
			gchar* _tmp13_;
#line 232 "/home/jens/Source/shotwell/src/AppDirs.vala"
			err = _inner_error_;
#line 232 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_inner_error_ = NULL;
#line 239 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_tmp8_ = g_file_get_path (dir);
#line 239 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_tmp9_ = _tmp8_;
#line 239 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_tmp10_ = err;
#line 239 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_tmp11_ = _tmp10_->message;
#line 239 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_tmp12_ = g_strdup_printf (_ ("Could not make directory %s writable: %s"), _tmp9_, _tmp11_);
#line 239 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_tmp13_ = _tmp12_;
#line 239 "/home/jens/Source/shotwell/src/AppDirs.vala"
			app_window_panic (_tmp13_);
#line 239 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_g_free0 (_tmp13_);
#line 239 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_g_free0 (_tmp9_);
#line 232 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_g_error_free0 (err);
#line 1831 "AppDirs.c"
		}
		__finally460:
#line 232 "/home/jens/Source/shotwell/src/AppDirs.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 232 "/home/jens/Source/shotwell/src/AppDirs.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 232 "/home/jens/Source/shotwell/src/AppDirs.vala"
			g_clear_error (&_inner_error_);
#line 232 "/home/jens/Source/shotwell/src/AppDirs.vala"
			return;
#line 1842 "AppDirs.c"
		}
	}
}


GFile*
app_dirs_get_cache_subdir (const gchar* name,
                           const gchar* subname)
{
	GFile* result = NULL;
	GFile* subdir = NULL;
	GFile* _tmp0_;
	GFile* _tmp1_;
	GFile* _tmp2_;
	GFile* _tmp3_;
	GFile* _tmp4_;
	GFile* _tmp16_;
	GError * _inner_error_ = NULL;
#line 244 "/home/jens/Source/shotwell/src/AppDirs.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 245 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp0_ = app_dirs_get_cache_dir ();
#line 245 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp1_ = _tmp0_;
#line 245 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp2_ = g_file_get_child (_tmp1_, name);
#line 245 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp3_ = _tmp2_;
#line 245 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_g_object_unref0 (_tmp1_);
#line 245 "/home/jens/Source/shotwell/src/AppDirs.vala"
	subdir = _tmp3_;
#line 246 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp4_ = subdir;
#line 246 "/home/jens/Source/shotwell/src/AppDirs.vala"
	app_dirs_ensure_writable (_tmp4_);
#line 247 "/home/jens/Source/shotwell/src/AppDirs.vala"
	if (subname != NULL) {
#line 1881 "AppDirs.c"
		GFile* _tmp5_;
		GFile* _tmp6_;
#line 248 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp5_ = subdir;
#line 248 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp6_ = g_file_get_child (_tmp5_, subname);
#line 248 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_g_object_unref0 (subdir);
#line 248 "/home/jens/Source/shotwell/src/AppDirs.vala"
		subdir = _tmp6_;
#line 1892 "AppDirs.c"
	}
	{
		GFile* _tmp7_;
#line 251 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp7_ = subdir;
#line 251 "/home/jens/Source/shotwell/src/AppDirs.vala"
		if (!g_file_query_exists (_tmp7_, NULL)) {
#line 1900 "AppDirs.c"
			GFile* _tmp8_;
#line 252 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_tmp8_ = subdir;
#line 252 "/home/jens/Source/shotwell/src/AppDirs.vala"
			g_file_make_directory_with_parents (_tmp8_, NULL, &_inner_error_);
#line 252 "/home/jens/Source/shotwell/src/AppDirs.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1908 "AppDirs.c"
				goto __catch461_g_error;
			}
		}
	}
	goto __finally461;
	__catch461_g_error:
	{
		GError* err = NULL;
		GFile* _tmp9_;
		gchar* _tmp10_;
		gchar* _tmp11_;
		GError* _tmp12_;
		const gchar* _tmp13_;
		gchar* _tmp14_;
		gchar* _tmp15_;
#line 250 "/home/jens/Source/shotwell/src/AppDirs.vala"
		err = _inner_error_;
#line 250 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_inner_error_ = NULL;
#line 254 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp9_ = subdir;
#line 254 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp10_ = g_file_get_path (_tmp9_);
#line 254 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp11_ = _tmp10_;
#line 254 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp12_ = err;
#line 254 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp13_ = _tmp12_->message;
#line 254 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp14_ = g_strdup_printf (_ ("Unable to create data subdirectory %s: %s"), _tmp11_, _tmp13_);
#line 254 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp15_ = _tmp14_;
#line 254 "/home/jens/Source/shotwell/src/AppDirs.vala"
		app_window_panic (_tmp15_);
#line 254 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_g_free0 (_tmp15_);
#line 254 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_g_free0 (_tmp11_);
#line 250 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_g_error_free0 (err);
#line 1950 "AppDirs.c"
	}
	__finally461:
#line 250 "/home/jens/Source/shotwell/src/AppDirs.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 250 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_g_object_unref0 (subdir);
#line 250 "/home/jens/Source/shotwell/src/AppDirs.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 250 "/home/jens/Source/shotwell/src/AppDirs.vala"
		g_clear_error (&_inner_error_);
#line 250 "/home/jens/Source/shotwell/src/AppDirs.vala"
		return NULL;
#line 1963 "AppDirs.c"
	}
#line 257 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp16_ = subdir;
#line 257 "/home/jens/Source/shotwell/src/AppDirs.vala"
	app_dirs_ensure_writable (_tmp16_);
#line 258 "/home/jens/Source/shotwell/src/AppDirs.vala"
	result = subdir;
#line 258 "/home/jens/Source/shotwell/src/AppDirs.vala"
	return result;
#line 1973 "AppDirs.c"
}


GFile*
app_dirs_get_lib_dir (void)
{
	GFile* result = NULL;
	GFile* install_dir = NULL;
	GFile* _tmp0_;
	GFile* _tmp1_;
	GFile* _tmp12_;
	GFile* _tmp13_;
	GFile* _tmp14_;
	GFile* _tmp15_;
	GFile* _tmp16_;
#line 262 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp0_ = app_dirs_get_install_dir ();
#line 262 "/home/jens/Source/shotwell/src/AppDirs.vala"
	install_dir = _tmp0_;
#line 265 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp1_ = install_dir;
#line 265 "/home/jens/Source/shotwell/src/AppDirs.vala"
	if (_tmp1_ == NULL) {
#line 1997 "AppDirs.c"
		GFile* _tmp2_;
		GFile* _tmp3_;
		gchar* _tmp4_;
		gchar* _tmp5_;
		gboolean _tmp6_;
		GFile* _tmp11_;
#line 267 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp2_ = app_dirs_get_exec_dir ();
#line 267 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp3_ = _tmp2_;
#line 267 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp4_ = g_file_get_path (_tmp3_);
#line 267 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp5_ = _tmp4_;
#line 267 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp6_ = g_str_has_suffix (_tmp5_, "src");
#line 267 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_g_free0 (_tmp5_);
#line 267 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_g_object_unref0 (_tmp3_);
#line 267 "/home/jens/Source/shotwell/src/AppDirs.vala"
		if (_tmp6_) {
#line 2020 "AppDirs.c"
			GFile* _tmp7_;
			GFile* _tmp8_;
			GFile* _tmp9_;
			GFile* _tmp10_;
#line 268 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_tmp7_ = app_dirs_get_exec_dir ();
#line 268 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_tmp8_ = _tmp7_;
#line 268 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_tmp9_ = g_file_get_parent (_tmp8_);
#line 268 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_tmp10_ = _tmp9_;
#line 268 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_g_object_unref0 (_tmp8_);
#line 268 "/home/jens/Source/shotwell/src/AppDirs.vala"
			result = _tmp10_;
#line 268 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_g_object_unref0 (install_dir);
#line 268 "/home/jens/Source/shotwell/src/AppDirs.vala"
			return result;
#line 2041 "AppDirs.c"
		}
#line 271 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp11_ = app_dirs_get_exec_dir ();
#line 271 "/home/jens/Source/shotwell/src/AppDirs.vala"
		result = _tmp11_;
#line 271 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_g_object_unref0 (install_dir);
#line 271 "/home/jens/Source/shotwell/src/AppDirs.vala"
		return result;
#line 2051 "AppDirs.c"
	}
#line 274 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp12_ = install_dir;
#line 274 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp13_ = g_file_get_child (_tmp12_, RESOURCES_LIB);
#line 274 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp14_ = _tmp13_;
#line 274 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp15_ = g_file_get_child (_tmp14_, "shotwell");
#line 274 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp16_ = _tmp15_;
#line 274 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_g_object_unref0 (_tmp14_);
#line 274 "/home/jens/Source/shotwell/src/AppDirs.vala"
	result = _tmp16_;
#line 274 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_g_object_unref0 (install_dir);
#line 274 "/home/jens/Source/shotwell/src/AppDirs.vala"
	return result;
#line 2071 "AppDirs.c"
}


GFile*
app_dirs_get_system_plugins_dir (void)
{
	GFile* result = NULL;
	GFile* _tmp0_;
	GFile* _tmp1_;
	GFile* _tmp2_;
	GFile* _tmp3_;
#line 278 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp0_ = app_dirs_get_lib_dir ();
#line 278 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp1_ = _tmp0_;
#line 278 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp2_ = g_file_get_child (_tmp1_, "plugins");
#line 278 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp3_ = _tmp2_;
#line 278 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_g_object_unref0 (_tmp1_);
#line 278 "/home/jens/Source/shotwell/src/AppDirs.vala"
	result = _tmp3_;
#line 278 "/home/jens/Source/shotwell/src/AppDirs.vala"
	return result;
#line 2097 "AppDirs.c"
}


GFile*
app_dirs_get_user_plugins_dir (void)
{
	GFile* result = NULL;
	GFile* _tmp0_;
	GFile* _tmp1_;
	GFile* _tmp2_;
	GFile* _tmp3_;
#line 282 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp0_ = app_dirs_get_data_dir ();
#line 282 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp1_ = _tmp0_;
#line 282 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp2_ = g_file_get_child (_tmp1_, "plugins");
#line 282 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp3_ = _tmp2_;
#line 282 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_g_object_unref0 (_tmp1_);
#line 282 "/home/jens/Source/shotwell/src/AppDirs.vala"
	result = _tmp3_;
#line 282 "/home/jens/Source/shotwell/src/AppDirs.vala"
	return result;
#line 2123 "AppDirs.c"
}


GFile*
app_dirs_get_log_file (void)
{
	GFile* result = NULL;
	const gchar* _tmp0_;
#line 286 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp0_ = g_getenv ("SHOTWELL_LOG_FILE");
#line 286 "/home/jens/Source/shotwell/src/AppDirs.vala"
	if (_tmp0_ != NULL) {
#line 2136 "AppDirs.c"
		const gchar* _tmp1_;
#line 287 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp1_ = g_getenv ("SHOTWELL_LOG_FILE");
#line 287 "/home/jens/Source/shotwell/src/AppDirs.vala"
		if (g_strcmp0 (_tmp1_, ":console:") == 0) {
#line 288 "/home/jens/Source/shotwell/src/AppDirs.vala"
			result = NULL;
#line 288 "/home/jens/Source/shotwell/src/AppDirs.vala"
			return result;
#line 2146 "AppDirs.c"
		} else {
			const gchar* _tmp2_;
			GFile* _tmp3_;
#line 290 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_tmp2_ = g_getenv ("SHOTWELL_LOG_FILE");
#line 290 "/home/jens/Source/shotwell/src/AppDirs.vala"
			_tmp3_ = g_file_new_for_path (_tmp2_);
#line 290 "/home/jens/Source/shotwell/src/AppDirs.vala"
			result = _tmp3_;
#line 290 "/home/jens/Source/shotwell/src/AppDirs.vala"
			return result;
#line 2158 "AppDirs.c"
		}
	} else {
		const gchar* _tmp4_;
		GFile* _tmp5_;
		GFile* _tmp6_;
		GFile* _tmp7_;
		GFile* _tmp8_;
		GFile* _tmp9_;
		GFile* _tmp10_;
#line 293 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp4_ = g_get_user_cache_dir ();
#line 293 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp5_ = g_file_new_for_path (_tmp4_);
#line 293 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp6_ = _tmp5_;
#line 293 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp7_ = g_file_get_child (_tmp6_, "shotwell");
#line 293 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp8_ = _tmp7_;
#line 293 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp9_ = g_file_get_child (_tmp8_, "shotwell.log");
#line 293 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp10_ = _tmp9_;
#line 293 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_g_object_unref0 (_tmp8_);
#line 293 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_g_object_unref0 (_tmp6_);
#line 293 "/home/jens/Source/shotwell/src/AppDirs.vala"
		result = _tmp10_;
#line 293 "/home/jens/Source/shotwell/src/AppDirs.vala"
		return result;
#line 2190 "AppDirs.c"
	}
}


GFile*
app_dirs_get_thumbnailer_bin (void)
{
	GFile* result = NULL;
#line 299 "/home/jens/Source/shotwell/src/AppDirs.vala"
	static const char filename[] = "shotwell-video-thumbnailer";
#line 2201 "AppDirs.c"
	GFile* f = NULL;
	GFile* _tmp0_;
	GFile* _tmp1_;
	GFile* _tmp2_;
	GFile* _tmp3_;
	GFile* _tmp4_;
	GFile* _tmp5_;
	GFile* _tmp6_;
#line 300 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp0_ = app_dirs_get_libexec_dir ();
#line 300 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp1_ = _tmp0_;
#line 300 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp2_ = g_file_get_child (_tmp1_, "thumbnailer");
#line 300 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp3_ = _tmp2_;
#line 300 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp4_ = g_file_get_child (_tmp3_, filename);
#line 300 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp5_ = _tmp4_;
#line 300 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_g_object_unref0 (_tmp3_);
#line 300 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_g_object_unref0 (_tmp1_);
#line 300 "/home/jens/Source/shotwell/src/AppDirs.vala"
	f = _tmp5_;
#line 301 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp6_ = f;
#line 301 "/home/jens/Source/shotwell/src/AppDirs.vala"
	if (!g_file_query_exists (_tmp6_, NULL)) {
#line 2232 "AppDirs.c"
		GFile* _tmp7_;
		GFile* _tmp8_;
		GFile* _tmp9_;
		GFile* _tmp10_;
		GFile* _tmp11_;
#line 303 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp7_ = app_dirs_get_libexec_dir ();
#line 303 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp8_ = _tmp7_;
#line 303 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp9_ = g_file_get_child (_tmp8_, "shotwell");
#line 303 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp10_ = _tmp9_;
#line 303 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp11_ = g_file_get_child (_tmp10_, filename);
#line 303 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_g_object_unref0 (f);
#line 303 "/home/jens/Source/shotwell/src/AppDirs.vala"
		f = _tmp11_;
#line 303 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_g_object_unref0 (_tmp10_);
#line 303 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_g_object_unref0 (_tmp8_);
#line 2256 "AppDirs.c"
	}
#line 305 "/home/jens/Source/shotwell/src/AppDirs.vala"
	result = f;
#line 305 "/home/jens/Source/shotwell/src/AppDirs.vala"
	return result;
#line 2262 "AppDirs.c"
}


GFile*
app_dirs_get_settings_migrator_bin (void)
{
	GFile* result = NULL;
#line 309 "/home/jens/Source/shotwell/src/AppDirs.vala"
	static const char filename[] = "shotwell-settings-migrator";
#line 2272 "AppDirs.c"
	GFile* f = NULL;
	GFile* _tmp0_;
	GFile* _tmp1_;
	GFile* _tmp2_;
	GFile* _tmp3_;
	GFile* _tmp4_;
	GFile* _tmp5_;
	GFile* _tmp6_;
#line 310 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp0_ = app_dirs_get_libexec_dir ();
#line 310 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp1_ = _tmp0_;
#line 310 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp2_ = g_file_get_child (_tmp1_, "settings-migrator");
#line 310 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp3_ = _tmp2_;
#line 310 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp4_ = g_file_get_child (_tmp3_, filename);
#line 310 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp5_ = _tmp4_;
#line 310 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_g_object_unref0 (_tmp3_);
#line 310 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_g_object_unref0 (_tmp1_);
#line 310 "/home/jens/Source/shotwell/src/AppDirs.vala"
	f = _tmp5_;
#line 311 "/home/jens/Source/shotwell/src/AppDirs.vala"
	_tmp6_ = f;
#line 311 "/home/jens/Source/shotwell/src/AppDirs.vala"
	if (!g_file_query_exists (_tmp6_, NULL)) {
#line 2303 "AppDirs.c"
		GFile* _tmp7_;
		GFile* _tmp8_;
		GFile* _tmp9_;
		GFile* _tmp10_;
		GFile* _tmp11_;
#line 313 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp7_ = app_dirs_get_libexec_dir ();
#line 313 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp8_ = _tmp7_;
#line 313 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp9_ = g_file_get_child (_tmp8_, "shotwell");
#line 313 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp10_ = _tmp9_;
#line 313 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_tmp11_ = g_file_get_child (_tmp10_, filename);
#line 313 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_g_object_unref0 (f);
#line 313 "/home/jens/Source/shotwell/src/AppDirs.vala"
		f = _tmp11_;
#line 313 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_g_object_unref0 (_tmp10_);
#line 313 "/home/jens/Source/shotwell/src/AppDirs.vala"
		_g_object_unref0 (_tmp8_);
#line 2327 "AppDirs.c"
	}
#line 315 "/home/jens/Source/shotwell/src/AppDirs.vala"
	result = f;
#line 315 "/home/jens/Source/shotwell/src/AppDirs.vala"
	return result;
#line 2333 "AppDirs.c"
}


AppDirs*
app_dirs_construct (GType object_type)
{
	AppDirs* self = NULL;
#line 7 "/home/jens/Source/shotwell/src/AppDirs.vala"
	self = (AppDirs*) g_type_create_instance (object_type);
#line 7 "/home/jens/Source/shotwell/src/AppDirs.vala"
	return self;
#line 2345 "AppDirs.c"
}


AppDirs*
app_dirs_new (void)
{
#line 7 "/home/jens/Source/shotwell/src/AppDirs.vala"
	return app_dirs_construct (TYPE_APP_DIRS);
#line 2354 "AppDirs.c"
}


static void
value_app_dirs_init (GValue* value)
{
#line 7 "/home/jens/Source/shotwell/src/AppDirs.vala"
	value->data[0].v_pointer = NULL;
#line 2363 "AppDirs.c"
}


static void
value_app_dirs_free_value (GValue* value)
{
#line 7 "/home/jens/Source/shotwell/src/AppDirs.vala"
	if (value->data[0].v_pointer) {
#line 7 "/home/jens/Source/shotwell/src/AppDirs.vala"
		app_dirs_unref (value->data[0].v_pointer);
#line 2374 "AppDirs.c"
	}
}


static void
value_app_dirs_copy_value (const GValue* src_value,
                           GValue* dest_value)
{
#line 7 "/home/jens/Source/shotwell/src/AppDirs.vala"
	if (src_value->data[0].v_pointer) {
#line 7 "/home/jens/Source/shotwell/src/AppDirs.vala"
		dest_value->data[0].v_pointer = app_dirs_ref (src_value->data[0].v_pointer);
#line 2387 "AppDirs.c"
	} else {
#line 7 "/home/jens/Source/shotwell/src/AppDirs.vala"
		dest_value->data[0].v_pointer = NULL;
#line 2391 "AppDirs.c"
	}
}


static gpointer
value_app_dirs_peek_pointer (const GValue* value)
{
#line 7 "/home/jens/Source/shotwell/src/AppDirs.vala"
	return value->data[0].v_pointer;
#line 2401 "AppDirs.c"
}


static gchar*
value_app_dirs_collect_value (GValue* value,
                              guint n_collect_values,
                              GTypeCValue* collect_values,
                              guint collect_flags)
{
#line 7 "/home/jens/Source/shotwell/src/AppDirs.vala"
	if (collect_values[0].v_pointer) {
#line 2413 "AppDirs.c"
		AppDirs * object;
		object = collect_values[0].v_pointer;
#line 7 "/home/jens/Source/shotwell/src/AppDirs.vala"
		if (object->parent_instance.g_class == NULL) {
#line 7 "/home/jens/Source/shotwell/src/AppDirs.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 2420 "AppDirs.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 7 "/home/jens/Source/shotwell/src/AppDirs.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 2424 "AppDirs.c"
		}
#line 7 "/home/jens/Source/shotwell/src/AppDirs.vala"
		value->data[0].v_pointer = app_dirs_ref (object);
#line 2428 "AppDirs.c"
	} else {
#line 7 "/home/jens/Source/shotwell/src/AppDirs.vala"
		value->data[0].v_pointer = NULL;
#line 2432 "AppDirs.c"
	}
#line 7 "/home/jens/Source/shotwell/src/AppDirs.vala"
	return NULL;
#line 2436 "AppDirs.c"
}


static gchar*
value_app_dirs_lcopy_value (const GValue* value,
                            guint n_collect_values,
                            GTypeCValue* collect_values,
                            guint collect_flags)
{
	AppDirs ** object_p;
	object_p = collect_values[0].v_pointer;
#line 7 "/home/jens/Source/shotwell/src/AppDirs.vala"
	if (!object_p) {
#line 7 "/home/jens/Source/shotwell/src/AppDirs.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 2452 "AppDirs.c"
	}
#line 7 "/home/jens/Source/shotwell/src/AppDirs.vala"
	if (!value->data[0].v_pointer) {
#line 7 "/home/jens/Source/shotwell/src/AppDirs.vala"
		*object_p = NULL;
#line 2458 "AppDirs.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 7 "/home/jens/Source/shotwell/src/AppDirs.vala"
		*object_p = value->data[0].v_pointer;
#line 2462 "AppDirs.c"
	} else {
#line 7 "/home/jens/Source/shotwell/src/AppDirs.vala"
		*object_p = app_dirs_ref (value->data[0].v_pointer);
#line 2466 "AppDirs.c"
	}
#line 7 "/home/jens/Source/shotwell/src/AppDirs.vala"
	return NULL;
#line 2470 "AppDirs.c"
}


GParamSpec*
param_spec_app_dirs (const gchar* name,
                     const gchar* nick,
                     const gchar* blurb,
                     GType object_type,
                     GParamFlags flags)
{
	ParamSpecAppDirs* spec;
#line 7 "/home/jens/Source/shotwell/src/AppDirs.vala"
	g_return_val_if_fail (g_type_is_a (object_type, TYPE_APP_DIRS), NULL);
#line 7 "/home/jens/Source/shotwell/src/AppDirs.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 7 "/home/jens/Source/shotwell/src/AppDirs.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 7 "/home/jens/Source/shotwell/src/AppDirs.vala"
	return G_PARAM_SPEC (spec);
#line 2490 "AppDirs.c"
}


gpointer
value_get_app_dirs (const GValue* value)
{
#line 7 "/home/jens/Source/shotwell/src/AppDirs.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_APP_DIRS), NULL);
#line 7 "/home/jens/Source/shotwell/src/AppDirs.vala"
	return value->data[0].v_pointer;
#line 2501 "AppDirs.c"
}


void
value_set_app_dirs (GValue* value,
                    gpointer v_object)
{
	AppDirs * old;
#line 7 "/home/jens/Source/shotwell/src/AppDirs.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_APP_DIRS));
#line 7 "/home/jens/Source/shotwell/src/AppDirs.vala"
	old = value->data[0].v_pointer;
#line 7 "/home/jens/Source/shotwell/src/AppDirs.vala"
	if (v_object) {
#line 7 "/home/jens/Source/shotwell/src/AppDirs.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, TYPE_APP_DIRS));
#line 7 "/home/jens/Source/shotwell/src/AppDirs.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 7 "/home/jens/Source/shotwell/src/AppDirs.vala"
		value->data[0].v_pointer = v_object;
#line 7 "/home/jens/Source/shotwell/src/AppDirs.vala"
		app_dirs_ref (value->data[0].v_pointer);
#line 2524 "AppDirs.c"
	} else {
#line 7 "/home/jens/Source/shotwell/src/AppDirs.vala"
		value->data[0].v_pointer = NULL;
#line 2528 "AppDirs.c"
	}
#line 7 "/home/jens/Source/shotwell/src/AppDirs.vala"
	if (old) {
#line 7 "/home/jens/Source/shotwell/src/AppDirs.vala"
		app_dirs_unref (old);
#line 2534 "AppDirs.c"
	}
}


void
value_take_app_dirs (GValue* value,
                     gpointer v_object)
{
	AppDirs * old;
#line 7 "/home/jens/Source/shotwell/src/AppDirs.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_APP_DIRS));
#line 7 "/home/jens/Source/shotwell/src/AppDirs.vala"
	old = value->data[0].v_pointer;
#line 7 "/home/jens/Source/shotwell/src/AppDirs.vala"
	if (v_object) {
#line 7 "/home/jens/Source/shotwell/src/AppDirs.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, TYPE_APP_DIRS));
#line 7 "/home/jens/Source/shotwell/src/AppDirs.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 7 "/home/jens/Source/shotwell/src/AppDirs.vala"
		value->data[0].v_pointer = v_object;
#line 2556 "AppDirs.c"
	} else {
#line 7 "/home/jens/Source/shotwell/src/AppDirs.vala"
		value->data[0].v_pointer = NULL;
#line 2560 "AppDirs.c"
	}
#line 7 "/home/jens/Source/shotwell/src/AppDirs.vala"
	if (old) {
#line 7 "/home/jens/Source/shotwell/src/AppDirs.vala"
		app_dirs_unref (old);
#line 2566 "AppDirs.c"
	}
}


static void
app_dirs_class_init (AppDirsClass * klass)
{
#line 7 "/home/jens/Source/shotwell/src/AppDirs.vala"
	app_dirs_parent_class = g_type_class_peek_parent (klass);
#line 7 "/home/jens/Source/shotwell/src/AppDirs.vala"
	((AppDirsClass *) klass)->finalize = app_dirs_finalize;
#line 2578 "AppDirs.c"
}


static void
app_dirs_instance_init (AppDirs * self)
{
#line 7 "/home/jens/Source/shotwell/src/AppDirs.vala"
	self->ref_count = 1;
#line 2587 "AppDirs.c"
}


static void
app_dirs_finalize (AppDirs * obj)
{
	AppDirs * self;
#line 7 "/home/jens/Source/shotwell/src/AppDirs.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_APP_DIRS, AppDirs);
#line 7 "/home/jens/Source/shotwell/src/AppDirs.vala"
	g_signal_handlers_destroy (self);
#line 2599 "AppDirs.c"
}


GType
app_dirs_get_type (void)
{
	static volatile gsize app_dirs_type_id__volatile = 0;
	if (g_once_init_enter (&app_dirs_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { value_app_dirs_init, value_app_dirs_free_value, value_app_dirs_copy_value, value_app_dirs_peek_pointer, "p", value_app_dirs_collect_value, "p", value_app_dirs_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (AppDirsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) app_dirs_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (AppDirs), 0, (GInstanceInitFunc) app_dirs_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType app_dirs_type_id;
		app_dirs_type_id = g_type_register_fundamental (g_type_fundamental_next (), "AppDirs", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&app_dirs_type_id__volatile, app_dirs_type_id);
	}
	return app_dirs_type_id__volatile;
}


gpointer
app_dirs_ref (gpointer instance)
{
	AppDirs * self;
	self = instance;
#line 7 "/home/jens/Source/shotwell/src/AppDirs.vala"
	g_atomic_int_inc (&self->ref_count);
#line 7 "/home/jens/Source/shotwell/src/AppDirs.vala"
	return instance;
#line 2628 "AppDirs.c"
}


void
app_dirs_unref (gpointer instance)
{
	AppDirs * self;
	self = instance;
#line 7 "/home/jens/Source/shotwell/src/AppDirs.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 7 "/home/jens/Source/shotwell/src/AppDirs.vala"
		APP_DIRS_GET_CLASS (self)->finalize (self);
#line 7 "/home/jens/Source/shotwell/src/AppDirs.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 2643 "AppDirs.c"
	}
}



